@@ -166,9 +166,17 @@ def install(
         ip = get_ipython()  # type: ignore
         from IPython.core.formatters import BaseFormatter
 
+        class RichFormatter(BaseFormatter):  # type: ignore
+            pprint: bool = True
+
+            def __call__(self, value: Any) -> Any:
+                if self.pprint:
+                    return ipy_display_hook(value)
+                else:
+                    return repr(value)
+
         # replace plain text formatter with rich formatter
-        rich_formatter = BaseFormatter()
-        rich_formatter.for_type(object, func=ipy_display_hook)
+        rich_formatter = RichFormatter()
         ip.display_formatter.formatters["text/plain"] = rich_formatter
     except Exception:
         sys.displayhook = display_hook
@@ -212,8 +220,8 @@ class Pretty(JupyterMixin):
         self._object = _object
         self.highlighter = highlighter or ReprHighlighter()
         self.indent_size = indent_size
-        self.justify = justify
-        self.overflow = overflow
+        self.justify: Optional["JustifyMethod"] = justify
+        self.overflow: Optional["OverflowMethod"] = overflow
         self.no_wrap = no_wrap
         self.indent_guides = indent_guides
         self.max_length = max_length
@@ -645,7 +653,7 @@ def traverse(
                 last=root,
             )
 
-            for last, field in loop_last(fields(obj)):
+            for last, field in loop_last(field for field in fields(obj) if field.repr):
                 if field.repr:
                     child_node = _traverse(getattr(obj, field.name))
                     child_node.key_repr = field.name
